@@ -158,7 +158,8 @@ void ProductMapping::checkProductInfo(const Bugzilla::Product::Ptr product)
         // renamed so we'll find the version with the lowest id instead
         // and that should technically have been the "default" version.
         Bugzilla::ProductVersion *lowestVersion = nullptr;
-        for (const auto &version : product->versions()) {
+        const QList<Bugzilla::ProductVersion *> versions = product->versions();
+        for (const auto &version : versions) {
             if (!lowestVersion || lowestVersion->id() > version->id()) {
                 lowestVersion = version;
             }
@@ -172,6 +173,8 @@ void ProductMapping::checkProductInfo(const Bugzilla::Product::Ptr product)
     // usually means that version is outdated and not supported anymore.
     const QStringList &inactiveVersions = product->inactiveVersions();
     m_bugzillaVersionDisabled = inactiveVersions.contains(m_bugzillaVersionString);
+
+    Q_EMIT resolved();
 }
 
 void ProductMapping::fallBackToKDE()
@@ -186,6 +189,8 @@ void ProductMapping::fallBackToKDE()
     m_bugzillaProductOriginal = m_bugzillaProduct;
     m_bugzillaProduct = QStringLiteral("kde");
     m_bugzillaManagerPtr->fetchProductInfo(m_bugzillaProduct);
+
+    Q_EMIT resolved();
 }
 
 QStringList ProductMapping::relatedBugzillaProducts() const
