@@ -115,5 +115,5 @@ void MsvcGenerator::LoadSymbol(const QString &module, DWORD64 dwBaseAddr)
 
     strOutput = QString::fromLatin1("Loaded %1 (%2)").arg(module).arg(symbolType);
 
-    emit DebugLine(strOutput);
+    Q_EMIT DebugLine(strOutput);
 }
