@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2009-2010 George Kiagiadakis <kiagiadakis.george@gmail.com>
-    SPDX-FileCopyrightText: 2021 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2021-2022 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -52,15 +52,15 @@ public:
     virtual QString simplifiedBacktrace() const;
 
     /*! Returns a value that indicates how much useful is the backtrace that we got */
-    virtual Usefulness backtraceUsefulness() const;
+    Q_INVOKABLE virtual BacktraceParser::Usefulness backtraceUsefulness() const;
 
     /*! Returns a short list of the first good functions that appear in the backtrace
      * (in the crashing thread). This is used for quering for duplicate reports.
      */
-    virtual QStringList firstValidFunctions() const;
+    Q_INVOKABLE virtual QStringList firstValidFunctions() const;
 
     /*! Returns a list of libraries/executables that are missing debug symbols. */
-    virtual QSet<QString> librariesWithMissingDebugSymbols() const;
+    Q_INVOKABLE virtual QStringList librariesWithMissingDebugSymbols() const;
 
     /*! Check if the crash is because of the client aborting after a compositor crash.
      * https://bugs.kde.org/show_bug.cgi?id=431561
